@@ -19,9 +19,8 @@ class Network3Medusa():
 
     def network3_medusa(self):
         self.py2output()
-        print(sys.getsizeof(self.output))
         raw_json=self.output.stdout.decode('utf-8')
-        if 'eth_admin_fec_state' in raw_json:
+        if self.command == "show interface":
             json_dict = json.loads(raw_json)
             first = True
             for interface in json_dict['TABLE_interface']['ROW_interface']:
@@ -41,6 +40,8 @@ class Network3Medusa():
             print("File size according to `FileInfoQuery`: ", info.size)            
             if WEBEX_ROOM:
                 self.send_webex_notification()
+        elif self.command == "show running-config":
+            print(raw_json)
         else:
             self.add_file_to_hedera(raw_json)
             if WEBEX_ROOM:
